searchNodes=[{"doc":"StructyRecord provides a Struct-like interface for your Records.Use your record's macros in the same module where it is defined!Access and update fields in your record through named macro calls.Create and update records at runtime (not limited to compile time).Calculate 1-based indexes to access record fields in :ets tables.","ref":"StructyRecord.html","title":"StructyRecord","type":"module"},{"doc":"Defines a module named alias that is also a Record composed of fields.Parametersalias is the name of the module being defined. It also serves as the tag parameter of Record.defrecord/3, which helps identify the record.fields specifies the shape of the record being defined. It is either:a list of Atom field names whose default values are always nila Keyword list of field names along with their own default valuesdo_block is an optional block of code that is passed into defmodule/2. It allows you to extend the module being defined with your own custom code, which has compile-time access to all the guards and macros described below.ResultsThe defined module contains the following guards, macros, and functions.Guards (available at compile time):is_record/1 to check if argument loosely matches this record's shapeMacros (available at compile time):{}/0 to create a new record with default values for all fields{}/1 to create a new record with the given fields and values{}/1 to get the zero-based index of the given field in a record{{}}/1 to convert a record into a list of its fields and values{{}}/2 to get the value of a given field in a given record{{}}/2 to assign the given fields and values in a given recordrecord?/1 to check if argument strictly matches this record's shaperecord/0 to create a new record with default values for all fieldsrecord/1 to create a new record with the given fields and valuesrecord/1 to get the zero-based index of the given field in a recordrecord/1 to convert a record into a list of its fields and valuesrecord/2 to get the value of a given field in a given recordrecord/2 to assign the given fields and values in a given recordget/2 to fetch the value of a given field in a given recordput/2 to assign the given fields and values inside a given recordget_${field}/1 to fetch the value of a specific field in a given recordput_${field}/2 to assign the value of a specific field in a given recordindex/1 to get the zero-based index of the given field in a recordkeypos/1 to get the 1-based index of the given field in a recordto_list/0 to get a template of fields and default values for this recordto_list/1 to convert a record into a list of its fields and valuesFunctions (available at runtime only):from_list/1 to create a new record with the given fields and valuesmerge/2 to assign the given fields and values inside a given recordinspect/2 to inspect the contents of a record using Kernel.inspect/2ExamplesActivate this macro in your environment:require StructyRecordDefine a structy record for a rectangle:StructyRecord.defrecord Rectangle, [:width, :height] do def area(r = record()) do get_width(r) * get_height(r) end def perimeter(record(width: w, height: h)) do 2 * (w + h) end def square?(record(width: same, height: same)), do: true def square?(_), do: false endActivate its macros in your environment:use RectangleCreate instances of your structy record:rect = Rectangle.{} #-&gt; {Rectangle, nil, nil} rect = Rectangle.{[]} #-&gt; {Rectangle, nil, nil} no_h = Rectangle.{[width: 1]} #-&gt; {Rectangle, 1, nil} no_w = Rectangle.{[height: 2]} #-&gt; {Rectangle, nil, 2} wide = Rectangle.{[width: 10, height: 5]} #-&gt; {Rectangle, 10, 5} tall = Rectangle.{[width: 4, height: 25]} #-&gt; {Rectangle, 4, 25} even = Rectangle.{[width: 10, height: 10]} #-&gt; {Rectangle, 10, 10}Inspect the contents of those instances:rect |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: nil, height: nil]}&quot; no_h |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 1, height: nil]}&quot; no_w |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: nil, height: 2]}&quot; wide |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 10, height: 5]}&quot; tall |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 4, height: 25]}&quot; even |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 10, height: 10]}&quot;Get values of fields in those instances:Rectangle.{{tall, :height}} #-&gt; 25 Rectangle.{[height: h]} = tall; h #-&gt; 25 tall |&gt; Rectangle.get_height() #-&gt; 25Set values of fields in those instances:Rectangle.{{even, width: 1}} #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.put(width: 1) #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.put_width(1) #-&gt; {Rectangle, 1, 10} Rectangle.{{even, width: 1, height: 2}} #-&gt; {Rectangle, 1, 2} even |&gt; Rectangle.put(width: 1, height: 2) #-&gt; {Rectangle, 1, 2} even |&gt; Rectangle.put_width(1) |&gt; Rectangle.put_height(2) #-&gt; {Rectangle, 1, 2}Use your custom code on those instances:rect |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * nil no_h |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 * nil no_w |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * 2 wide |&gt; Rectangle.area() #-&gt; 50 tall |&gt; Rectangle.area() #-&gt; 100 even |&gt; Rectangle.area() #-&gt; 100 rect |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + nil no_h |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 + nil no_w |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + 2 wide |&gt; Rectangle.perimeter() #-&gt; 30 tall |&gt; Rectangle.perimeter() #-&gt; 58 even |&gt; Rectangle.perimeter() #-&gt; 40 rect |&gt; Rectangle.square?() #-&gt; true no_h |&gt; Rectangle.square?() #-&gt; false no_w |&gt; Rectangle.square?() #-&gt; false wide |&gt; Rectangle.square?() #-&gt; false tall |&gt; Rectangle.square?() #-&gt; false even |&gt; Rectangle.square?() #-&gt; true","ref":"StructyRecord.html#defrecord/3","title":"StructyRecord.defrecord/3","type":"macro"},{"doc":"StructyRecordStructyRecord provides a Struct-like interface for your Records.Use your record's macros in the same module where it is defined!Access and update fields in your record through named macro calls.Create and update records at runtime (not limited to compile time).Calculate 1-based indexes to access record fields in :ets tables.","ref":"readme.html","title":"StructyRecord","type":"extras"},{"doc":"The package is available in Hex and can be installed by adding structy_record to your list of dependencies in mix.exs:def deps do [ {:structy_record, &quot;~&gt; 0.2.0&quot;, runtime: false} ] end","ref":"readme.html#setup","title":"StructyRecord - Setup","type":"extras"},{"doc":"To get started, see the documentation for StructyRecord.defrecord/3:iex&gt; h StructyRecord.defrecordExamplesActivate this macro in your environment:require StructyRecordDefine a structy record for a rectangle:StructyRecord.defrecord Rectangle, [:width, :height] do def area(r = record()) do get_width(r) * get_height(r) end def perimeter(record(width: w, height: h)) do 2 * (w + h) end def square?(record(width: same, height: same)), do: true def square?(_), do: false endActivate its macros in your environment:use RectangleCreate instances of your structy record:rect = Rectangle.{} #-&gt; {Rectangle, nil, nil} rect = Rectangle.{[]} #-&gt; {Rectangle, nil, nil} no_h = Rectangle.{[width: 1]} #-&gt; {Rectangle, 1, nil} no_w = Rectangle.{[height: 2]} #-&gt; {Rectangle, nil, 2} wide = Rectangle.{[width: 10, height: 5]} #-&gt; {Rectangle, 10, 5} tall = Rectangle.{[width: 4, height: 25]} #-&gt; {Rectangle, 4, 25} even = Rectangle.{[width: 10, height: 10]} #-&gt; {Rectangle, 10, 10}Inspect the contents of those instances:rect |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: nil, height: nil]}&quot; no_h |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 1, height: nil]}&quot; no_w |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: nil, height: 2]}&quot; wide |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 10, height: 5]}&quot; tall |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 4, height: 25]}&quot; even |&gt; Rectangle.inspect() #-&gt; &quot;Rectangle.{[width: 10, height: 10]}&quot;Get values of fields in those instances:Rectangle.{{tall, :height}} #-&gt; 25 Rectangle.{[height: h]} = tall; h #-&gt; 25 tall |&gt; Rectangle.get_height() #-&gt; 25Set values of fields in those instances:Rectangle.{{even, width: 1}} #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.put(width: 1) #-&gt; {Rectangle, 1, 10} even |&gt; Rectangle.put_width(1) #-&gt; {Rectangle, 1, 10} Rectangle.{{even, width: 1, height: 2}} #-&gt; {Rectangle, 1, 2} even |&gt; Rectangle.put(width: 1, height: 2) #-&gt; {Rectangle, 1, 2} even |&gt; Rectangle.put_width(1) |&gt; Rectangle.put_height(2) #-&gt; {Rectangle, 1, 2}Use your custom code on those instances:rect |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * nil no_h |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 * nil no_w |&gt; Rectangle.area() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil * 2 wide |&gt; Rectangle.area() #-&gt; 50 tall |&gt; Rectangle.area() #-&gt; 100 even |&gt; Rectangle.area() #-&gt; 100 rect |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + nil no_h |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: 1 + nil no_w |&gt; Rectangle.perimeter() #-&gt; (ArithmeticError) bad argument in arithmetic expression: nil + 2 wide |&gt; Rectangle.perimeter() #-&gt; 30 tall |&gt; Rectangle.perimeter() #-&gt; 58 even |&gt; Rectangle.perimeter() #-&gt; 40 rect |&gt; Rectangle.square?() #-&gt; true no_h |&gt; Rectangle.square?() #-&gt; false no_w |&gt; Rectangle.square?() #-&gt; false wide |&gt; Rectangle.square?() #-&gt; false tall |&gt; Rectangle.square?() #-&gt; false even |&gt; Rectangle.square?() #-&gt; true","ref":"readme.html#usage","title":"StructyRecord - Usage","type":"extras"},{"doc":"Like my work? 👍 Please spare a life today as thanks! 🐄🐖🐑🐔🐣🐟✨🙊✌Why? For 💕 ethics, the 🌎 environment, and 💪 health; see link above. 🙇(the ISC license)Copyright 2019 Suraj N. Kurapati https://github.com/sunakuPermission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.THE SOFTWARE IS PROVIDED &quot;AS IS&quot; AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.","ref":"readme.html#license","title":"StructyRecord - License","type":"extras"},{"doc":"","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"This release adds a convenient new shorthand syntax for the record() macro, renames field accessors to prevent name collisions, clarifies docs, and more.Incompatible:Rename record!/1 function to from_list/1.Rename record!/2 function to merge/2.Add get_ and put_ prefix to field accessors.Field names can no longer conflict with defined macros &amp; functions.Don't check argument types in Elixiry interface.It broke simple macro expansion when used in case/function clauses.Enhancements:Add Module.{_} syntax for Module.record(_).https://stackoverflow.com/a/51313720/120075Add inspect/2 for friendlier inspection.Add to_list/0 to get record's template.Add to_list/1 alias for record/1 macro.Add index/1 to get field index in tuple.Add get/2 macro as an alias to record/2.Add put/2 macro as an alias to record/2.Define documentation for all macros and functions.Housekeeping:record?/1 macro: only use pattern matching check.keypos/1 macro: don't call module being defined.mix.exs: drop application(); use runtime: false.","ref":"changelog.html#version-0-2-0-2021-02-18","title":"CHANGELOG - Version 0.2.0 (2021-02-18)","type":"extras"},{"doc":"Initial release! 🎉 Announced on ElixirForum and Reddit.","ref":"changelog.html#version-0-1-0-2019-10-26","title":"CHANGELOG - Version 0.1.0 (2019-10-26)","type":"extras"}]